processor

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2025 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Package processor handles the downloading and processing of map data.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ProcessLocations

func ProcessLocations(client *http.Client, m config.Map, force bool) error

ProcessLocations handles the logic for fetching and converting location data. It supports inline data from config, iZurvive, and Xam formats.

func ProcessTiles

func ProcessTiles(client *http.Client, m config.Map, concurrency, defaultZoom int, force, fastCheck bool)

ProcessTiles handles the downloading or slicing of map tiles. It supports both downloading from a URL template and slicing from a single large image.

Types

type TileCoordinate

type TileCoordinate struct {
	Z, X, Y int
}

TileCoordinate represents a specific tile.

Jump to