Documentation
¶
Overview ¶
Package processor handles the downloading and processing of map data.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProcessLocations ¶
ProcessLocations handles the logic for fetching and converting location data. It supports inline data from config, iZurvive, and Xam formats.
Types ¶
type TileCoordinate ¶
type TileCoordinate struct {
Z, X, Y int
}
TileCoordinate represents a specific tile.
Click to show internal directories.
Click to hide internal directories.